@@ -138,7 +138,7 @@ func (c *command) create(cmd *cobra.Command, _ []string) error {
 	}
 
 	// add Schema Registry Cluster if its provisioned
-	if srCluster != nil {
+	if _, ok := srCluster.GetIdOk(); ok {
 		createPipeline.Spec.StreamGovernanceCluster = &streamdesignerv1.ObjectReference{Id: srCluster.GetId()}
 	}
 
