@@ -5,12 +5,9 @@ import (
 	"encoding/json"
 	"io"
 	"net/http"
-	"strings"
 	"time"
 
 	metricsv2 "github.com/confluentinc/ccloud-sdk-go-v2/metrics/v2"
-
-	testserver "github.com/confluentinc/cli/test/test-server"
 )
 
 type flatQueryResponse struct {
@@ -22,35 +19,30 @@ type responseDataPoint struct {
 	Value     float32   `json:"value"`
 }
 
-func newMetricsClient(baseUrl, userAgent string, unsafeTrace, isTest bool) *metricsv2.APIClient {
+type MetricsClient struct {
+	*metricsv2.APIClient
+	authToken string
+}
+
+func NewMetricsClient(url, userAgent string, unsafeTrace bool, authToken string) *MetricsClient {
 	cfg := metricsv2.NewConfiguration()
 	cfg.Debug = unsafeTrace
 	cfg.HTTPClient = newRetryableHttpClient(unsafeTrace)
-	cfg.Servers = metricsv2.ServerConfigurations{{URL: getMetricsServerUrl(baseUrl, isTest)}}
+	cfg.Servers = metricsv2.ServerConfigurations{{URL: url}}
 	cfg.UserAgent = userAgent
 
-	return metricsv2.NewAPIClient(cfg)
-}
-
-func getMetricsServerUrl(baseURL string, isTest bool) string {
-	if isTest {
-		return testserver.TestV2CloudUrl.String()
+	return &MetricsClient{
+		APIClient: metricsv2.NewAPIClient(cfg),
+		authToken: authToken,
 	}
-	if strings.Contains(baseURL, "devel") {
-		return "https://devel-sandbox-api.telemetry.aws.confluent.cloud"
-	} else if strings.Contains(baseURL, "stag") {
-		return "https://stag-sandbox-api.telemetry.aws.confluent.cloud"
-	}
-	return "https://api.telemetry.confluent.cloud"
 }
 
-func (c *Client) metricsApiContext() context.Context {
-	return context.WithValue(context.Background(), metricsv2.ContextAccessToken, c.JwtToken)
+func (c *MetricsClient) metricsApiContext() context.Context {
+	return context.WithValue(context.Background(), metricsv2.ContextAccessToken, c.authToken)
 }
 
-func (c *Client) MetricsDatasetQuery(dataset string, query metricsv2.QueryRequest) (*metricsv2.QueryResponse, *http.Response, error) {
-	req := c.MetricsClient.Version2Api.V2MetricsDatasetQueryPost(c.metricsApiContext(), dataset).QueryRequest(query)
-	return c.MetricsClient.Version2Api.V2MetricsDatasetQueryPostExecute(req)
+func (c *MetricsClient) MetricsDatasetQuery(dataset string, query metricsv2.QueryRequest) (*metricsv2.QueryResponse, *http.Response, error) {
+	return c.Version2Api.V2MetricsDatasetQueryPost(c.metricsApiContext(), dataset).QueryRequest(query).Execute()
 }
 
 func UnmarshalFlatQueryResponseIfDataSchemaMatchError(err error, metricsResponse *metricsv2.QueryResponse, httpResp *http.Response) error {
