@@ -24,26 +24,22 @@ func (c *Client) orgApiContext() context.Context {
 }
 
 func (c *Client) CreateOrgEnvironment(environment orgv2.OrgV2Environment) (orgv2.OrgV2Environment, error) {
-	req := c.OrgClient.EnvironmentsOrgV2Api.CreateOrgV2Environment(c.orgApiContext()).OrgV2Environment(environment)
-	res, r, err := c.OrgClient.EnvironmentsOrgV2Api.CreateOrgV2EnvironmentExecute(req)
+	res, r, err := c.OrgClient.EnvironmentsOrgV2Api.CreateOrgV2Environment(c.orgApiContext()).OrgV2Environment(environment).Execute()
 	return res, errors.CatchCCloudV2Error(err, r)
 }
 
 func (c *Client) GetOrgEnvironment(envId string) (orgv2.OrgV2Environment, error) {
-	req := c.OrgClient.EnvironmentsOrgV2Api.GetOrgV2Environment(c.orgApiContext(), envId)
-	res, r, err := c.OrgClient.EnvironmentsOrgV2Api.GetOrgV2EnvironmentExecute(req)
+	res, r, err := c.OrgClient.EnvironmentsOrgV2Api.GetOrgV2Environment(c.orgApiContext(), envId).Execute()
 	return res, errors.CatchCCloudV2Error(err, r)
 }
 
 func (c *Client) UpdateOrgEnvironment(envId string, updateEnvironment orgv2.OrgV2Environment) (orgv2.OrgV2Environment, error) {
-	req := c.OrgClient.EnvironmentsOrgV2Api.UpdateOrgV2Environment(c.orgApiContext(), envId).OrgV2Environment(updateEnvironment)
-	res, r, err := c.OrgClient.EnvironmentsOrgV2Api.UpdateOrgV2EnvironmentExecute(req)
+	res, r, err := c.OrgClient.EnvironmentsOrgV2Api.UpdateOrgV2Environment(c.orgApiContext(), envId).OrgV2Environment(updateEnvironment).Execute()
 	return res, errors.CatchCCloudV2Error(err, r)
 }
 
 func (c *Client) DeleteOrgEnvironment(envId string) error {
-	req := c.OrgClient.EnvironmentsOrgV2Api.DeleteOrgV2Environment(c.orgApiContext(), envId)
-	r, err := c.OrgClient.EnvironmentsOrgV2Api.DeleteOrgV2EnvironmentExecute(req)
+	r, err := c.OrgClient.EnvironmentsOrgV2Api.DeleteOrgV2Environment(c.orgApiContext(), envId).Execute()
 	return errors.CatchCCloudV2Error(err, r)
 }
 
@@ -72,17 +68,15 @@ func (c *Client) executeListEnvironments(pageToken string) (orgv2.OrgV2Environme
 	if pageToken != "" {
 		req = req.PageToken(pageToken)
 	}
-	return c.OrgClient.EnvironmentsOrgV2Api.ListOrgV2EnvironmentsExecute(req)
+	return req.Execute()
 }
 
 func (c *Client) GetOrgOrganization(orgId string) (orgv2.OrgV2Organization, *http.Response, error) {
-	req := c.OrgClient.OrganizationsOrgV2Api.GetOrgV2Organization(c.orgApiContext(), orgId)
-	return c.OrgClient.OrganizationsOrgV2Api.GetOrgV2OrganizationExecute(req)
+	return c.OrgClient.OrganizationsOrgV2Api.GetOrgV2Organization(c.orgApiContext(), orgId).Execute()
 }
 
 func (c *Client) UpdateOrgOrganization(orgId string, updateOrganization orgv2.OrgV2Organization) (orgv2.OrgV2Organization, *http.Response, error) {
-	req := c.OrgClient.OrganizationsOrgV2Api.UpdateOrgV2Organization(c.orgApiContext(), orgId).OrgV2Organization(updateOrganization)
-	return c.OrgClient.OrganizationsOrgV2Api.UpdateOrgV2OrganizationExecute(req)
+	return c.OrgClient.OrganizationsOrgV2Api.UpdateOrgV2Organization(c.orgApiContext(), orgId).OrgV2Organization(updateOrganization).Execute()
 }
 
 func (c *Client) ListOrgOrganizations() ([]orgv2.OrgV2Organization, error) {
@@ -110,5 +104,5 @@ func (c *Client) executeListOrganizations(pageToken string) (orgv2.OrgV2Organiza
 	if pageToken != "" {
 		req = req.PageToken(pageToken)
 	}
-	return c.OrgClient.OrganizationsOrgV2Api.ListOrgV2OrganizationsExecute(req)
+	return req.Execute()
 }
