@@ -31,9 +31,9 @@ func PrintOptionState(prefix string, isEnabled bool, maxCol int) {
 func PrintWelcomeHeader() {
 	// Print welcome message
 	output.Printf("Welcome! \n")
-	output.Printf("You can press Ctrl-Q or type exit; to quit the client. \n\n")
+	output.Printf("To exit, press Ctrl-Q or type \"exit;\". \n\n")
 
 	// Print shortcuts
 	output.Printf("\033[0m%s \033[0;36m%s \033[0m", "[Ctrl-Q]", "Quit")
-	output.Printf("\033[0m%s \033[0;36m%s \033[0m \n", "[Ctrl-S]", "Smart Completion")
+	output.Printf("\033[0m%s \033[0;36m%s \033[0m \n", "[Ctrl-S]", "Toggle Smart Completion")
 }
